@@ -20,30 +20,24 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const _ = imports.gettext.gettext;
+import gettext from 'gettext';
 
-const Geocode = imports.gi.GeocodeGlib;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const Soup = imports.gi.Soup;
+const _ = gettext.gettext;
 
-const Application = imports.application;
-const Maps = imports.gi.GnomeMaps;
-const OSMConnection = imports.osmConnection;
-const OSMTypes = imports.osmTypes;
-const OSMTypeSearchEntry = imports.osmTypeSearchEntry;
-const OSMUtils = imports.osmUtils;
-const Utils = imports.utils;
-const Wikipedia = imports.wikipedia;
+import GeocodeGlib from 'gi://GeocodeGlib';
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-var Response = {
-    UPLOADED: 0,
-    DELETED: 1,
-    CANCELLED: 2,
-    ERROR: 3
-};
+import {Application} from './application.js';
+import GnomeMaps from 'gi://GnomeMaps';
+import {OSMConnection} from './osmConnection.js';
+import * as OSMTypes from './osmTypes.js';
+import {OSMTypeSearchEntry} from './osmTypeSearchEntry.js';
+import * as OSMUtils from './osmUtils.js';
+import * as Utils from './utils.js';
+import * as Wikipedia from './wikipedia.js';
 
 /*
  * enumeration representing
@@ -79,7 +73,7 @@ var _osmPhoneRewriteFunc = function(text) {
     if (GLib.uri_parse_scheme(text) === 'tel') {
         let afterTel = text.replace('tel:', '');
 
-        return Soup.uri_decode(afterTel.split(';')[0]);
+        return GLib.uri_unescape_string(afterTel.split(';')[0], null);
     } else {
         return text;
     }
@@ -94,7 +88,7 @@ var _osmEmailRewriteFunc = function(text) {
     if (GLib.uri_parse_scheme(text) === 'mailto') {
         let afterMailto = text.replace('mailto:', '');
 
-        return Soup.uri_decode(afterMailto.split('?')[0]);
+        return GLib.uri_unescape_string(afterMailto.split('?')[0], null);
     } else {
         return text;
     }
@@ -146,7 +140,7 @@ const OSM_FIELDS = [
         name: _("Phone"),
         tag: 'phone',
         type: EditFieldType.TEXT,
-        rewriteFunc: this._osmPhoneRewriteFunc,
+        rewriteFunc: _osmPhoneRewriteFunc,
         hint: _("Phone number. Use the international format, " +
                 "starting with a + sign. Beware of local privacy " +
                 "laws, especially for private phone numbers.")
@@ -156,7 +150,7 @@ const OSM_FIELDS = [
         tag: 'email',
         type: EditFieldType.TEXT,
         validate: Utils.isValidEmail,
-        rewriteFunc: this._osmEmailRewriteFunc,
+        rewriteFunc: _osmEmailRewriteFunc,
         validateError: _("This is not a valid e-mail address. Make sure to not include the mailto: protocol prefix."),
         hint: _("Contact e-mail address for inquiries. " +
                 "Add only email addresses that are intended to be publicly used.")
@@ -166,7 +160,7 @@ const OSM_FIELDS = [
         tag: 'wikipedia',
         type: EditFieldType.TEXT,
         validate: Wikipedia.isValidWikipedia,
-        rewriteFunc: this._osmWikipediaRewriteFunc,
+        rewriteFunc: _osmWikipediaRewriteFunc,
         hint: _("The format used should include the language code " +
                 "and the article title like “en:Article title”.")
     },
@@ -258,15 +252,9 @@ const OSM_FIELDS = [
         hint: _("Information used to inform other mappers about non-obvious information about an element, the author’s intent when creating it, or hints for further improvement.")
     }];
 
-const OSMEditAddress = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/osm-edit-address.ui',
-    Children: [ 'street',
-                'number',
-                'post',
-                'city' ],
-}, class OSMEditAddress extends Gtk.Grid {
+export class OSMEditAddress extends Gtk.Grid {
 
-    _init(params) {
+    constructor(params) {
         let street = params.street;
         delete params.street;
 
@@ -279,7 +267,7 @@ const OSMEditAddress = GObject.registerClass({
         let city = params.city;
         delete params.city;
 
-        super._init(params);
+        super(params);
 
         if (street)
             this.street.text = street;
@@ -293,52 +281,47 @@ const OSMEditAddress = GObject.registerClass({
         if (city)
             this.city.text = city;
     }
-});
+}
 
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/osm-edit-address.ui',
+    Children: [ 'street',
+                'number',
+                'post',
+                'city' ],
+}, OSMEditAddress);
 
-var OSMEditDialog = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/osm-edit-dialog.ui',
-    InternalChildren: [ 'cancelButton',
-                        'backButton',
-                        'nextButton',
-                        'stack',
-                        'editorGrid',
-                        'commentTextView',
-                        'addFieldPopoverGrid',
-                        'addFieldButton',
-                        'typeSearchGrid',
-                        'typeLabel',
-                        'typeButton',
-                        'typeValueLabel',
-                        'recentTypesLabel',
-                        'recentTypesListBox',
-                        'hintPopover',
-                        'hintLabel',
-                        'headerBar'],
-}, class OSMEditDialog extends Gtk.Dialog {
+export class OSMEditDialog extends Gtk.Dialog {
 
-    _init(params) {
-        this._place = params.place;
+    static Response = {
+        UPLOADED: 0,
+        DELETED: 1,
+        CANCELLED: 2,
+        ERROR: 3
+    };
+
+    constructor(params) {
+        let place = params.place;
         delete params.place;
 
-        this._addLocation = params.addLocation;
+        let addLocation = params.addLocation;
         delete params.addLocation;
 
-        this._latitude = params.latitude;
+        let latitude = params.latitude;
         delete params.latitude;
 
-        this._longitude = params.longitude;
+        let longitude = params.longitude;
         delete params.longitude;
 
         /* This is a construct-only property and cannot be set by GtkBuilder */
         params.use_header_bar = true;
 
-        super._init(params);
+        super(params);
 
         /* I could not get this widget working from within the widget template
          * this results in a segfault. The widget definition is left in-place,
          * but commented-out in the template file */
-        this._typeSearch = new OSMTypeSearchEntry.OSMTypeSearchEntry();
+        this._typeSearch = new OSMTypeSearchEntry();
         this._typeSearchGrid.attach(this._typeSearch, 0, 0, 1, 1);
         this._typeSearch.visible = true;
         this._typeSearch.can_focus = true;
@@ -349,9 +332,10 @@ var OSMEditDialog = GObject.registerClass({
         });
 
         this._cancellable = new Gio.Cancellable();
-        this._cancellable.connect(() => this.response(Response.CANCELLED));
+        this._cancellable.connect(() => this.response(OSMEditDialog.Response.CANCELLED));
 
-        this.connect('delete-event', () => this._cancellable.cancel());
+        this.connect('response', () => this._cancellable.cancel());
+        this.connect('close-request', () => this._cancellable.cancel());
 
         this._isEditing = false;
         this._nextButton.connect('clicked', () => this._onNextClicked());
@@ -359,23 +343,23 @@ var OSMEditDialog = GObject.registerClass({
         this._backButton.connect('clicked', () => this._onBackClicked());
         this._typeButton.connect('clicked', () => this._onTypeClicked());
 
-        if (this._addLocation) {
+        if (addLocation) {
             this._headerBar.title = C_("dialog title", "Add to OpenStreetMap");
             this._typeLabel.visible = true;
             this._typeButton.visible = true;
 
             /* the OSMObject ID, version, and changeset ID is unknown for now */
             let newNode =
-                Maps.OSMNode.new(0, 0, 0, this._longitude, this._latitude);
+                GnomeMaps.OSMNode.new(0, 0, 0, longitude, latitude);
             /* set a placeholder name tag to always get a name entry for new
              * locations */
             newNode.set_tag('name', '');
             this._loadOSMData(newNode);
             this._isEditing = true;
-            this._osmType = Geocode.PlaceOsmType.NODE;
+            this._osmType = GeocodeGlib.PlaceOsmType.NODE;
         } else {
-            this._osmType = this._place.osmType;
-            Application.osmEdit.fetchObject(this._place,
+            this._osmType = place.osmType;
+            Application.osmEdit.fetchObject(place,
                                             this._onObjectFetched.bind(this),
                                             this._cancellable);
         }
@@ -491,10 +475,15 @@ var OSMEditDialog = GObject.registerClass({
         let recentTypes = OSMTypes.recentTypesStore.recentTypes;
 
         if (recentTypes.length > 0) {
-            let children = this._recentTypesListBox.get_children();
+            let children = [];
 
-            for (let i = 0; i < children.length; i++) {
-                this._recentTypesListBox.remove(children[i]);
+            for (let child of this._recentTypesListBox) {
+                if (child instanceof Gtk.ListBoxRow)
+                    children.push(child);
+            }
+
+            for (let child of children) {
+                this._recentTypesListBox.remove(child);
             }
 
             this._recentTypesLabel.visible = true;
@@ -540,7 +529,7 @@ var OSMEditDialog = GObject.registerClass({
     }
 
     _onCancelClicked() {
-        this.response(Response.CANCELLED);
+        this.response(OSMEditDialog.Response.CANCELLED);
     }
 
     _onBackClicked() {
@@ -566,10 +555,10 @@ var OSMEditDialog = GObject.registerClass({
 
     _onObjectUploaded(success, status) {
         if (success) {
-            this.response(Response.UPLOADED);
+            this.response(OSMEditDialog.Response.UPLOADED);
         } else {
             this._showError(status);
-            this.response(Response.ERROR);
+            this.response(OSMEditDialog.Response.ERROR);
         }
     }
 
@@ -579,7 +568,7 @@ var OSMEditDialog = GObject.registerClass({
         let statusMessage =
             error ? error.message : OSMConnection.getStatusMessage(status);
         let messageDialog =
-            new Gtk.MessageDialog({ transient_for: this.get_toplevel(),
+            new Gtk.MessageDialog({ transient_for: this.get_root(),
                                     destroy_with_parent: true,
                                     message_type: Gtk.MessageType.ERROR,
                                     buttons: Gtk.ButtonsType.OK,
@@ -587,9 +576,9 @@ var OSMEditDialog = GObject.registerClass({
                                     text: _("An error has occurred"),
                                     secondary_text: statusMessage });
 
-        messageDialog.run();
-        messageDialog.destroy();
-        this.response(Response.ERROR);
+        messageDialog.connect('response', () => messageDialog.destroy());
+        messageDialog.show();
+        this.response(OSMEditDialog.Response.ERROR);
     }
 
     /* GtkContainer.child_get_property doesn't seem to be usable from GJS */
@@ -606,8 +595,7 @@ var OSMEditDialog = GObject.registerClass({
     }
 
     _addOSMEditDeleteButton(fieldSpec) {
-        let deleteButton = Gtk.Button.new_from_icon_name('user-trash-symbolic',
-                                                         Gtk.IconSize.BUTTON);
+        let deleteButton = Gtk.Button.new_from_icon_name('user-trash-symbolic');
         let styleContext = deleteButton.get_style_context();
         let rows = fieldSpec.rows || 1;
 
@@ -648,11 +636,13 @@ var OSMEditDialog = GObject.registerClass({
     }
 
     _showHintPopover(entry, hint) {
-        if (this._hintPopover.visible) {
+        if (this._hintPopover && this._hintPopover.visible) {
             this._hintPopover.popdown();
+            this._hintPopover = null;
         } else {
-            this._hintPopover.relative_to = entry;
-            this._hintLabel.label = hint;
+            let label = new Gtk.Label({ label: hint });
+            this._hintPopover = new Gtk.Popover({ child: label });
+            this._hintPopover.set_parent(entry);
             this._hintPopover.popup();
         }
     }
@@ -681,8 +671,13 @@ var OSMEditDialog = GObject.registerClass({
             entry.placeholder_text = fieldSpec.placeHolder;
 
         entry.connect('changed', () => {
-            if (fieldSpec.rewriteFunc)
-                entry.text = fieldSpec.rewriteFunc(entry.text);
+            if (fieldSpec.rewriteFunc) {
+                let rewrittenText = fieldSpec.rewriteFunc(entry.text);
+
+                if (rewrittenText !== entry.text)
+                    entry.text = rewrittenText;
+            }
+
             this._osmObject.set_tag(fieldSpec.tag, entry.text);
 
             this._validateTextEntry(fieldSpec, entry);
@@ -726,12 +721,16 @@ var OSMEditDialog = GObject.registerClass({
             this._nextButton.sensitive = true;
         });
 
+        // TODO: this doesn't work in GTK4, since SpinButton doesn't extend
+        // Entry, maybe put the hint button beside the spin button?
+        /*
         if (fieldSpec.hint) {
             spinbutton.secondary_icon_name = 'dialog-information-symbolic';
             spinbutton.connect('icon-press', (iconPos, event) => {
                 this._showHintPopover(spinbutton, fieldSpec.hint);
             });
         }
+        */
 
         this._editorGrid.attach(spinbutton, 1, this._currentRow, 1, 1);
         spinbutton.show();
@@ -791,12 +790,15 @@ var OSMEditDialog = GObject.registerClass({
     /* update visible items in the "Add Field" popover */
     _updateAddFieldMenu() {
         /* clear old items */
-        let children = this._addFieldPopoverGrid.get_children();
         let hasAllFields = true;
+        let children = [];
 
-        for (let i = 0; i < children.length; i++) {
-            let button = children[i];
-            button.destroy();
+        for (let child of this._addFieldPopoverGrid) {
+            children.push(child);
+        }
+
+        for (let child of children) {
+            this._addFieldPopoverGrid.remove(child);
         }
 
         /* add selectable items */
@@ -826,6 +828,7 @@ var OSMEditDialog = GObject.registerClass({
 
                 button.connect('clicked', () => {
                     this._addFieldButton.active = false;
+                    this._addFieldPopover.popdown();
                     this._addOSMField(fieldSpec);
                     /* add a "placeholder" empty OSM tag to keep the add field
                      * menu updated, these tags will be filtered out if nothing
@@ -904,4 +907,24 @@ var OSMEditDialog = GObject.registerClass({
         this._updateTypeButton();
         this._stack.visible_child_name = 'editor';
     }
-});
+}
+
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/osm-edit-dialog.ui',
+    InternalChildren: [ 'cancelButton',
+                        'backButton',
+                        'nextButton',
+                        'stack',
+                        'editorGrid',
+                        'commentTextView',
+                        'addFieldPopover',
+                        'addFieldPopoverGrid',
+                        'addFieldButton',
+                        'typeSearchGrid',
+                        'typeLabel',
+                        'typeButton',
+                        'typeValueLabel',
+                        'recentTypesLabel',
+                        'recentTypesListBox',
+                        'headerBar'],
+}, OSMEditDialog);
