@@ -17,25 +17,17 @@
  * Author: Jonas Danielsson <jonas@threetimestwo.org>
  */
 
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const PlaceFormatter = imports.placeFormatter;
-const PlaceStore = imports.placeStore;
-const Utils = imports.utils;
+import {PlaceFormatter} from './placeFormatter.js';
+import {PlaceStore} from './placeStore.js';
+import * as Utils from './utils.js';
 
-var ROW_HEIGHT = 55;
+export class PlaceListRow extends Gtk.ListBoxRow {
 
-var PlaceListRow = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/place-list-row.ui',
-    InternalChildren: [ 'icon',
-                        'name',
-                        'details',
-                        'typeIcon' ],
-}, class PlaceListRow extends Gtk.ListBoxRow {
-
-    _init(params) {
+    constructor(params) {
         let place = params.place;
         delete params.place;
 
@@ -45,28 +37,27 @@ var PlaceListRow = GObject.registerClass({
         let type = params.type;
         delete params.type;
 
-        params.height_request = ROW_HEIGHT;
-        super._init(params);
+        super(params);
         this.update(place, type, searchString);
     }
 
     update(place, type, searchString) {
         this.place = place;
-        let formatter = new PlaceFormatter.PlaceFormatter(this.place);
-        this.title = formatter.title;
+        let formatter = new PlaceFormatter(this.place);
         let markup = GLib.markup_escape_text(formatter.title, -1);
 
         this._name.label = this._boldMatch(markup, searchString);
         this._details.label = GLib.markup_escape_text(formatter.getDetailsString(),-1);
-        this._icon.gicon = place.icon;
+        this._details.visible = this._details.label.length > 0;
+
+        if (place.icon)
+            this._icon.gicon = place.icon;
 
         if (type === PlaceStore.PlaceType.RECENT ||
             type === PlaceStore.PlaceType.RECENT_ROUTE)
             this._typeIcon.icon_name = 'document-open-recent-symbolic';
         else if (type === PlaceStore.PlaceType.FAVORITE)
             this._typeIcon.icon_name = 'starred-symbolic';
-        else if (type === PlaceStore.PlaceType.CONTACT)
-            this._typeIcon.icon_name = 'avatar-default-symbolic';
         else
             this._typeIcon.icon_name = null;
     }
@@ -83,4 +74,12 @@ var PlaceListRow = GObject.registerClass({
         }
         return title;
     }
-});
+}
+
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/place-list-row.ui',
+    InternalChildren: [ 'icon',
+                        'name',
+                        'details',
+                        'typeIcon' ],
+}, PlaceListRow);
