@@ -17,17 +17,21 @@
  * Author: Amisha Singla <amishas157@gmail.com>
  */
 
-const Gtk = imports.gi.Gtk;
-const Mainloop = imports.mainloop;
+import GLib from 'gi://GLib';
+import Gtk from 'gi://Gtk';
 
-const Application = imports.application;
-const PrintLayout = imports.printLayout;
-const TransitPrintLayout = imports.transitPrintLayout;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import {LongPrintLayout} from './longPrintLayout.js';
+import {ShortPrintLayout} from './shortPrintLayout.js';
+import {TransitPrintLayout} from './transitPrintLayout.js';
+import * as Utils from './utils.js';
 
 const _MIN_TIME_TO_ABORT = 3000;
 
-var PrintOperation = class PrintOperation {
+/* Following constant has unit as meters */
+const _SHORT_LAYOUT_MAX_DISTANCE = 3000;
+
+export class PrintOperation {
 
     constructor(params) {
         this._mainWindow = params.mainWindow;
@@ -61,21 +65,40 @@ var PrintOperation = class PrintOperation {
         let width = context.get_width();
         let height = context.get_height();
 
-        Mainloop.timeout_add(_MIN_TIME_TO_ABORT, () => {
+        if (selectedTransitItinerary) {
+            this._layout =
+                new TransitPrintLayout({ itinerary: selectedTransitItinerary,
+                                         pageWidth: width,
+                                         pageHeight: height,
+                                         mainWindow: this._mainWindow });
+        } else {
+            // TODO: for now just use short layout, as we don't have minimaps
+            this._layout = new ShortPrintLayout({ route: route,
+                                                  pageWidth: width,
+                                                  pageHeight: height,
+                                                  mainWindow: this._mainWindow });
+            /*
+            if (route.distance > _SHORT_LAYOUT_MAX_DISTANCE) {
+                this._layout = new LongPrintLayout({ route: route,
+                                                     pageWidth: width,
+                                                     pageHeight: height,
+                                                     mainWindow: this._mainWindow });
+            } else {
+                this._layout = new ShortPrintLayout({ route: route,
+                                                      pageWidth: width,
+                                                      pageHeight: height,
+                                                      mainWindow: this._mainWindow });
+            }
+            */
+        }
+
+        GLib.timeout_add(null, _MIN_TIME_TO_ABORT, () => {
             if (!this._layout.renderFinished) {
                 this._abortDialog.show();
             }
             return false;
-        }, null);
+        });
 
-        if (selectedTransitItinerary) {
-            this._layout =
-                new TransitPrintLayout.TransitPrintLayout({ itinerary: selectedTransitItinerary,
-                                                            pageWidth: width,
-                                                            pageHeight: height });
-        } else {
-            this._layout = PrintLayout.newFromRoute(route, width, height);
-        }
         this._layout.render();
     }
 
@@ -89,11 +112,15 @@ var PrintOperation = class PrintOperation {
     }
 
     _paginate(operation, context) {
-        if (this._layout.renderFinished) {
-            operation.set_n_pages(this._layout.numPages);
-            this._abortDialog.close();
+        if (this._layout) {
+            if (this._layout.renderFinished) {
+                operation.set_n_pages(this._layout.numPages);
+                this._abortDialog.close();
+            }
+            return this._layout.renderFinished;
+        } else {
+            return false;
         }
-        return this._layout.renderFinished;
     }
 
     _drawPage(operation, context, page_num, data) {
@@ -116,4 +143,4 @@ var PrintOperation = class PrintOperation {
             Utils.debug('Failed to print: %s'.format(e.message));
         }
     }
-};
+}
