@@ -20,61 +20,65 @@
  *         Jonas Danielsson <jonas@threetimestwo.org>
  */
 
-const Gdk = imports.gi.Gdk;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+import Gdk from 'gi://Gdk';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
 /* Abstract search result popover that progagates keypress events from a
    focus-taking internal widget to the spawning search entry widget */
-var SearchPopover = GObject.registerClass({
-    Abstract: true
-}, class SearchPopover extends Gtk.Popover {
+export class SearchPopover extends Gtk.Popover {
 
-    _init(props) {
-        super._init(props);
+    constructor(props) {
+        let entry = props.entry;
+        delete props.entry;
 
-        this._entry = this.relative_to;
+        super(props);
+
+        this._entry = entry;
 
         // We need to propagate events to the listbox so that we can
         // keep typing while selecting a place. But we do not want to
         // propagate the 'enter' key press if there is a selection.
-        this._entry.connect('key-press-event',
-                            this._propagateKeys.bind(this));
-        this._entry.connect('button-press-event', () => this._list.unselect_all());
+        this._keyController = new Gtk.EventControllerKey();
+        this.add_controller(this._keyController);
+        this._keyController.connect('key-pressed',
+                                    this._propagateKeys.bind(this));
+
+        this._buttonPressGesture = new Gtk.GestureSingle();
+        this._entry.add_controller(this._buttonPressGesture);
+        this._buttonPressGesture.connect('begin',
+                                         () => this._list.unselect_all());
+
+        this._numResults = 0;
+
+        this.add_css_class('suggestions');
     }
 
-    _propagateKeys(entry, event) {
-        let keyval = event.get_keyval()[1];
-
+    _propagateKeys(controller, keyval, keycode, state) {
         if (keyval === Gdk.KEY_Escape) {
             this.hide();
             this._list.unselect_all();
-            return Gdk.EVENT_STOP;
-        }
-
-        if (keyval === Gdk.KEY_Return ||
-            keyval === Gdk.KEY_KP_ENTER ||
-            keyval === Gdk.KEY_ISO_Enter) {
+        } else if (keyval === Gdk.KEY_Return ||
+                   keyval === Gdk.KEY_KP_ENTER ||
+                   keyval === Gdk.KEY_ISO_Enter) {
 
             // If we get an 'enter' keypress and we have a selected
             // row, we do not want to propagate the event.
             let row = this._list.get_selected_row();
+
             if (this.visible && row) {
                 row.activate();
-                return Gdk.EVENT_STOP;
             } else {
-                return Gdk.EVENT_PROPAGATE;
+                controller.forward(this._entry);
             }
-        }
+        } else if (keyval === Gdk.KEY_KP_Up ||
+                   keyval === Gdk.KEY_Up ||
+                   keyval === Gdk.KEY_KP_Down ||
+                   keyval === Gdk.KEY_Down) {
 
-        if (keyval === Gdk.KEY_KP_Up ||
-            keyval === Gdk.KEY_Up ||
-            keyval === Gdk.KEY_KP_Down ||
-            keyval === Gdk.KEY_Down) {
-
-            let length = this._list.get_children().length;
+            let length = this._numResults;
             if (length === 0) {
-                return Gdk.EVENT_PROPAGATE;
+                controller.forward(this._entry);
             }
 
             let direction = (keyval === Gdk.KEY_KP_Up || keyval === Gdk.KEY_Up) ? -1 : 1;
@@ -92,10 +96,17 @@ var SearchPopover = GObject.registerClass({
             } else {
                 this._list.unselect_all();
             }
-            return Gdk.EVENT_STOP;
+        } else {
+            if (keyval === Gdk.KEY_space) {
+                /* forwarding space seems to not work for some reason,
+                 * work around by manually injecting a space into the entry string
+                 */
+                this._entry.set_text(this._entry.text + ' ');
+                this._entry.set_position(this._entry.text.length);
+            } else {
+                controller.forward(this._entry);
+            }
         }
-
-        return Gdk.EVENT_PROPAGATE;
     }
 
     /* Selects given row and ensures that it is visible. */
@@ -107,5 +118,9 @@ var SearchPopover = GObject.registerClass({
             adjustment.clamp_page(allocation.y, allocation.y + allocation.height);
         }
     }
-});
+}
+
+GObject.registerClass({
+    Abstract: true
+}, SearchPopover);
 
