@@ -17,66 +17,49 @@
  * Author: Jonas Danielson <jonas@threetimestwo.org>
  */
 
-const Gdk = imports.gi.Gdk;
-const Geocode = imports.gi.GeocodeGlib;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const GWeather = imports.gi.GWeather;
-const Soup = imports.gi.Soup;
+import Gdk from 'gi://Gdk';
+import GeocodeGlib from 'gi://GeocodeGlib';
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import GWeather from 'gi://GWeather';
 
-const Application = imports.application;
-const PlaceFormatter = imports.placeFormatter;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import {PlaceFormatter} from './placeFormatter.js';
+import * as Utils from './utils.js';
 
 const _WEATHER_APPID = 'org.gnome.Weather';
 const _CLOCKS_APPID = 'org.gnome.clocks';
 
-var Response = {
-    SUCCESS: 0,
-    CANCEL: 1
-};
-
 const _NUM_VISIBLE = 4;
 
-var SendToDialog = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/send-to-dialog.ui',
-    InternalChildren: [ 'list',
-                        'weatherRow',
-                        'weatherLabel',
-                        'weatherIcon',
-                        'clocksRow',
-                        'clocksLabel',
-                        'clocksIcon',
-                        'cancelButton',
-                        'summaryLabel',
-                        'summaryUrl',
-                        'copyButton',
-                        'emailButton',
-                        'checkInButton',
-                        'scrolledWindow' ]
-}, class SendToDialog extends Gtk.Dialog {
+export class SendToDialog extends Gtk.Dialog {
 
-    _init(params) {
-        this._place = params.place;
-        this._location = this._place.location;
+    static Response = {
+        SUCCESS: 0,
+        CANCEL: 1
+    };
+
+    constructor(params) {
+        let place = params.place;
         delete params.place;
 
-        this._mapView = params.mapView;
+        let mapView = params.mapView;
         delete params.mapView;
 
-        let showCheckIn = params.showCheckIn || false;
-        delete params.showCheckIn;
-
         params.use_header_bar = true;
-        super._init(params);
+        super(params);
+
+        this._place = place;
+        this._location = this._place.location;
+        this._mapView = mapView;
 
         this._scrolledWindow.min_content_height = 40 * _NUM_VISIBLE;
         this.get_header_bar().subtitle = this._place.name;
 
         this._cancelButton.connect('clicked',
-                                   () => this.response(Response.CANCEL));
+                                   () => this.response(SendToDialog.Response.CANCEL));
 
         this._list.connect('row-activated', (list, row) => this._activateRow(row));
 
@@ -89,19 +72,6 @@ var SendToDialog = GObject.registerClass({
                 row.set_header(null);
         });
 
-        if (showCheckIn) {
-            Application.checkInManager.bind_property('hasCheckIn',
-                                                     this._checkInButton, 'visible',
-                                                     GObject.BindingFlags.DEFAULT |
-                                                     GObject.BindingFlags.SYNC_CREATE);
-
-            this._checkInButton.connect('clicked', () => {
-                Application.checkInManager.showCheckInDialog(this.get_toplevel(),
-                                                             this._place,
-                                                             false);
-            });
-        }
-
         this.connect('show', () => {
             this._summaryLabel.label = this._getSummary();
             let osmuri = GLib.markup_escape_text(this._getOSMURI(), -1);
@@ -153,7 +123,7 @@ var SendToDialog = GObject.registerClass({
         });
 
         /* Hide the list box if it is empty */
-        if (this._list.get_children().length == 0) {
+        if (!this._list.get_first_child()) {
             this._scrolledWindow.hide();
         }
     }
@@ -165,7 +135,7 @@ var SendToDialog = GObject.registerClass({
         let place = this._place;
         let lines = [];
 
-        let formatter = new PlaceFormatter.PlaceFormatter(place);
+        let formatter = new PlaceFormatter(place);
 
         if (!place.isCurrentLocation)
             lines.push(formatter.title);
@@ -182,7 +152,7 @@ var SendToDialog = GObject.registerClass({
     }
 
     _getOSMURI() {
-        let view = this._mapView.view;
+        let viewport = this._mapView.map.viewport;
         let place = this._place;
 
         let base = 'https://openstreetmap.org';
@@ -194,51 +164,47 @@ var SendToDialog = GObject.registerClass({
             return '%s?mlat=%f&mlon=%f&zoom=%d'.format(base,
                                                        this._location.latitude,
                                                        this._location.longitude,
-                                                       view.zoom_level);
+                                                       viewport.zoom_level);
         }
     }
 
     _copySummary() {
         let summary = '%s\n%s'.format(this._getSummary(), this._getOSMURI());
+        let clipboard = this.get_clipboard();
 
-        let display = Gdk.Display.get_default();
-        let clipboard = Gtk.Clipboard.get_default(display);
-        clipboard.set_text(summary, -1);
-        this.response(Response.SUCCESS);
+        clipboard.set(summary);
+        this.response(SendToDialog.Response.SUCCESS);
     }
 
     _emailSummary() {
-        let title = new PlaceFormatter.PlaceFormatter(this._place).title;
+        let title = new PlaceFormatter(this._place).title;
         let summary = "%s\n%s".format(this._getSummary(), this._getOSMURI());
-        let uri = 'mailto:?subject=%s&body=%s'.format(Soup.URI.encode(title, null),
-                                                      Soup.URI.encode(summary, null));
+        let uri = 'mailto:?subject=%s&body=%s'.format(GLib.uri_escape_string(title, null, false),
+                                                      GLib.uri_escape_string(summary, null, false));
 
         try {
           Gio.app_info_launch_default_for_uri(uri, this._getAppLaunchContext());
         } catch(e) {
           Utils.showDialog(_("Failed to open URI"), Gtk.MessageType.ERROR,
-                           this.get_toplevel());
+                           this);
           Utils.debug('failed to open URI: %s'.format(e.message));
         }
 
-        this.response(Response.SUCCESS);
+        this.response(SendToDialog.Response.SUCCESS);
     }
 
     _getAppLaunchContext() {
-        let timestamp = Gtk.get_current_event_time();
-        let display = Gdk.Display.get_default();
         let ctx = Gdk.Display.get_default().get_app_launch_context();
-        let screen = display.get_default_screen();
 
-        ctx.set_timestamp(timestamp);
-        ctx.set_screen(screen);
+        // GdkAppLaunchContext uses second-precision timestamps
+        ctx.set_timestamp(GLib.get_real_time() / 1000000);
 
         return ctx;
     }
 
     _activateRow(row) {
         if (row === this._weatherRow || row === this._clocksRow) {
-            let timestamp = Gtk.get_current_event_time();
+            let timestamp = GLib.get_real_time() / 1000000;
 
             let action;
             let appId;
@@ -255,25 +221,44 @@ var SendToDialog = GObject.registerClass({
                                  new GLib.Variant('v', this._city.serialize()),
                                  timestamp);
         } else if (row instanceof OpenWithRow) {
-            let uri = this._location.to_uri(Geocode.LocationURIScheme.GEO);
+            let uri = this._location.to_uri(GeocodeGlib.LocationURIScheme.GEO);
             row.appinfo.launch_uris([ uri ], this._getAppLaunchContext());
         }
-        this.response(Response.SUCCESS);
+        this.response(SendToDialog.Response.SUCCESS);
     }
-});
+}
 
-var OpenWithRow = GObject.registerClass({
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/send-to-dialog.ui',
+    InternalChildren: [ 'list',
+                        'weatherRow',
+                        'weatherLabel',
+                        'weatherIcon',
+                        'clocksRow',
+                        'clocksLabel',
+                        'clocksIcon',
+                        'cancelButton',
+                        'summaryLabel',
+                        'summaryUrl',
+                        'copyButton',
+                        'emailButton',
+                        'scrolledWindow' ]
+}, SendToDialog);
+
+export class OpenWithRow extends Gtk.ListBoxRow {
+    constructor(params) {
+        let appinfo = params.appinfo;
+        delete params.appinfo;
+
+        super(params);
+
+        this._label.label = _("Open with %s").format(appinfo.get_name());
+        this._icon.gicon = appinfo.get_icon();
+    }
+}
+
+GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/open-with-row.ui',
     InternalChildren: [ 'label',
                         'icon' ],
-}, class OpenWithRow extends Gtk.ListBoxRow {
-    _init(params) {
-        this.appinfo = params.appinfo;
-        delete params.appinfo;
-
-        super._init(params);
-
-        this._label.label = _("Open with %s").format(this.appinfo.get_name());
-        this._icon.gicon = this.appinfo.get_icon();
-    }
-});
+}, OpenWithRow);
