@@ -19,47 +19,42 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const Gdk = imports.gi.Gdk;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+import Gdk from 'gi://Gdk';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const Transit = imports.transit;
+import * as Transit from './transit.js';
 
-var TransitArrivalRow = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/transit-arrival-row.ui',
-    InternalChildren: ['arrivalLabel',
-                       'timeLabel',
-                       'eventBox',
-                       'separator']
-}, class TransitArrivalRow extends Gtk.ListBoxRow {
+export class TransitArrivalRow extends Gtk.ListBoxRow {
 
-    _init(params) {
-        this._itinerary = params.itinerary;
+    constructor(params) {
+        let itinerary = params.itinerary;
         delete params.itinerary;
 
-        this._mapView = params.mapView;
+        let mapView = params.mapView;
         delete params.mapView;
 
-        super._init(params);
-
-        let lastLeg = this._itinerary.legs[this._itinerary.legs.length - 1];
+        super(params);
+        let lastLeg = itinerary.legs[itinerary.legs.length - 1];
 
+        this._mapView = mapView;
         this._arrivalLabel.label = Transit.getArrivalLabel(lastLeg);
         this._timeLabel.label = lastLeg.prettyPrintArrivalTime();
 
-        this._eventBox.connect('event', (widget, event) => {
-            this._onEvent(event, lastLeg.toCoordinate);
-            return true;
-        });
+        this._buttonPressGesture = new Gtk.GestureSingle();
+        this.add_controller(this._buttonPressGesture);
+        this._buttonPressGesture.connect('begin',
+                                         () => this._onPress(lastLeg.toCoordinate));
     }
 
-    _onEvent(event, coord) {
-        let [isButton, button] = event.get_button();
-        let type = event.get_event_type();
-
-        if (isButton && button === 1 && type === Gdk.EventType.BUTTON_PRESS) {
-            this._mapView.view.zoom_level = 16;
-            this._mapView.view.center_on(coord[0], coord[1]);
-        }
+    _onPress(coord) {
+        this._mapView.map.go_to_full(coord[0], coord[1], 16);
     }
-});
+}
+
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/transit-arrival-row.ui',
+    InternalChildren: ['arrivalLabel',
+                       'timeLabel',
+                       'separator']
+}, TransitArrivalRow);
