@@ -27,16 +27,16 @@
  * https://transport.opendata.ch/docs.html
  */
 
-const Champlain = imports.gi.Champlain;
-const GLib = imports.gi.GLib;
-const Soup = imports.gi.Soup;
+import GLib from 'gi://GLib';
+import Shumate from 'gi://Shumate';
+import Soup from 'gi://Soup';
 
-const Application = imports.application;
-const GraphHopperTransit = imports.graphHopperTransit;
-const HVT = imports.hvt;
-const HTTP = imports.http;
-const TransitPlan = imports.transitPlan;
-const Utils = imports.utils;
+import {Application} from '../application.js';
+import * as GraphHopperTransit from '../graphHopperTransit.js';
+import * as HVT from '../hvt.js';
+import {Query} from '../http.js';
+import {Itinerary, Leg, RouteType, Stop} from '../transitPlan.js';
+import * as Utils from '../utils.js';
 
 const BASE_URL = 'https://transport.opendata.ch';
 const API_VERSION = 'v1';
@@ -96,7 +96,7 @@ const Category = {
 // gap to use when fetching additional routes
 const GAP_BEFORE_MORE_RESULTS = 120;
 
-var OpendataCH = class OpendataCH {
+export class OpendataCH {
     constructor() {
         this._session = new Soup.Session({ user_agent : 'gnome-maps/' + pkg.version });
         this._plan = Application.routingDelegator.transitRouter.plan;
@@ -143,19 +143,21 @@ var OpendataCH = class OpendataCH {
             this._fetchResults();
         } else {
             let location = points[index].place.location;
-            let query = new HTTP.Query({ x: location.latitude,
-                                         y: location.longitude });
-            let uri = new Soup.URI(BASE_URL + '/' + API_VERSION + '/locations?' +
-                                   query.toString());
-            let request = new Soup.Message({ method: 'GET', uri: uri });
+            let query = new Query({ x: location.latitude,
+                                    y: location.longitude });
+            let uri = BASE_URL + '/' + API_VERSION + '/locations?' + query.toString();
+            let request = Soup.Message('GET', uri);
 
-            this._session.queue_message(request, (obj, message) => {
-                if (message.status_code !== Soup.Status.OK) {
-                    Utils.debug('Failed to get location: ' + message.status_code);
+            this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, null,
+                                              (source, res) => {
+                if (request.get_status() !== Soup.Status.OK) {
+                    Utils.debug('Failed to get location: ' + request.get_status());
                     this._plan.requestFailed();
                     this._plan.reset();
                 } else {
-                    let result = JSON.parse(message.response_body.data);
+                    let buffer =
+                        this._session.send_and_read_finish(res).get_data();
+                    let result = JSON.parse(Utils.getBufferText(buffer));
 
                     Utils.debug('locations: ' + JSON.stringify(result, null, 2));
 
@@ -191,19 +193,20 @@ var OpendataCH = class OpendataCH {
 
     _fetchResults() {
         let query = this._getQuery();
-        let uri = new Soup.URI(BASE_URL + '/' + API_VERSION + '/connections?' +
-                               query.toString(true));
-        let request = new Soup.Message({ method: 'GET', uri: uri });
+        let uri = BASE_URL + '/' + API_VERSION + '/connections?' + query.toString(true);
+        let request = Soup.Message.new('GET', uri);
 
-        Utils.debug('uri: ' + uri.to_string(true));
+        Utils.debug('uri: ' + uri);
 
-        this._session.queue_message(request, (obj, message) => {
-            if (message.status_code !== Soup.Status.OK) {
-                Utils.debug('Failed to get trip: ' + message.status_code);
+        this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, null,
+                                          (source, res) => {
+            if (request.get_status() !== Soup.Status.OK) {
+                Utils.debug('Failed to get trip: ' + request.get_status());
                 this._plan.requestFailed();
                 this._plan.reset();
             } else {
-                let result = JSON.parse(message.response_body.data);
+                let buffer = this._session.send_and_read_finish(res).get_data();
+                let result = JSON.parse(Utils.getBufferText(buffer));
                 Utils.debug('result: ' + JSON.stringify(result, null, 2));
 
                 if (result.connections && result.connections.length > 0) {
@@ -233,10 +236,10 @@ var OpendataCH = class OpendataCH {
         let [startTime,] = this._parseTime(from.departure);
         let [endTime,] = this._parseTime(to.arrival);
 
-        return new TransitPlan.Itinerary({ duration:  duration,
-                                           departure: startTime,
-                                           arrival:   endTime,
-                                           legs:      legs });
+        return new Itinerary({ duration:  duration,
+                               departure: startTime,
+                               arrival:   endTime,
+                               legs:      legs });
     }
 
     /**
@@ -294,23 +297,23 @@ var OpendataCH = class OpendataCH {
         let [departureX, departureY, arrivalX, arrivalY] =
             this._getCoordsForSection(section, index, sections);
 
-        let result = new TransitPlan.Leg({ departure:            departureTime,
-                                           arrival:              arrivalTime,
-                                           from:                 from,
-                                           to:                   to,
-                                           headsign:             headsign,
-                                           fromCoordinate:       [departureX,
-                                                                  departureY],
-                                           toCoordinate:         [arrivalX,
-                                                                  arrivalY],
-                                           route:                route,
-                                           routeType:            routeType,
-                                           polyline:             polyline,
-                                           isTransit:            isTransit,
-                                           duration:             duration,
-                                           agencyName:           agencyName,
-                                           agencyTimezoneOffset: tzOffset,
-                                           tripShortName:        route });
+        let result = new Leg({ departure:            departureTime,
+                               arrival:              arrivalTime,
+                               from:                 from,
+                               to:                   to,
+                               headsign:             headsign,
+                               fromCoordinate:       [departureX,
+                                                      departureY],
+                               toCoordinate:         [arrivalX,
+                                                      arrivalY],
+                               route:                route,
+                               routeType:            routeType,
+                               polyline:             polyline,
+                               isTransit:            isTransit,
+                               duration:             duration,
+                               agencyName:           agencyName,
+                               agencyTimezoneOffset: tzOffset,
+                               tripShortName:        route });
 
         if (journey)
             result.intermediateStops = this._createIntermediateStops(journey);
@@ -391,18 +394,18 @@ var OpendataCH = class OpendataCH {
 
             section.journey.passList.forEach((pass) => {
                 let coordinate = pass.location.coordinate;
-                polyline.push(new Champlain.Coordinate({ latitude:  coordinate.x,
-                                                         longitude: coordinate.y }));
+                polyline.push(new Shumate.Coordinate({ latitude:  coordinate.x,
+                                                       longitude: coordinate.y }));
             });
         } else {
             let [departureX, departureY, arrivalX, arrivalY] =
                 this._getCoordsForSection(section, index, sections);
 
             polyline =
-                [new Champlain.Coordinate({ latitude:  departureX,
-                                            longitude: departureY }),
-                 new Champlain.Coordinate({ latitude:  arrivalX,
-                                            longitude: arrivalY })];
+                [new Shumate.Coordinate({ latitude:  departureX,
+                                          longitude: departureY }),
+                 new Shumate.Coordinate({ latitude:  arrivalX,
+                                          longitude: arrivalY })];
         }
 
         return polyline;
@@ -433,12 +436,12 @@ var OpendataCH = class OpendataCH {
         if (!departure)
             departure = arrival;
 
-        return new TransitPlan.Stop({ name:                 pass.station.name,
-                                      arrival:              arrival,
-                                      departure:            departure,
-                                      agencyTimezoneOffset: departureTzOffset || arrivalTzOffset,
-                                      coordinate: [pass.location.coordinate.x,
-                                                   pass.location.coordinate.y] });
+        return new Stop({ name:                 pass.station.name,
+                          arrival:              arrival,
+                          departure:            departure,
+                          agencyTimezoneOffset: departureTzOffset || arrivalTzOffset,
+                          coordinate: [pass.location.coordinate.x,
+                                       pass.location.coordinate.y] });
     }
 
     // get a time suitably formatted for the the query param
@@ -504,7 +507,7 @@ var OpendataCH = class OpendataCH {
                 params.date = this._query.date;
         }
 
-        let query = new HTTP.Query(params);
+        let query = new Query(params);
 
         if (this._viaLocations.length > 0) {
             this._viaLocations.forEach((p) => { query.add('via', p); });
@@ -528,13 +531,13 @@ var OpendataCH = class OpendataCH {
 
     _transportationForTransitType(type) {
         switch (type) {
-            case TransitPlan.RouteType.BUS:
+            case RouteType.BUS:
                 return Transportations.BUS;
-            case TransitPlan.RouteType.TRAM:
+            case RouteType.TRAM:
                 return Transportations.TRAM;
-            case TransitPlan.RouteType.TRAIN:
+            case RouteType.TRAIN:
                 return Transportations.TRAIN;
-            case TransitPlan.RouteType.FERRY:
+            case RouteType.FERRY:
                 return Transportations.SHIP;
             default:
                 return null;
