@@ -27,16 +27,16 @@
  * https://www.trafiklab.se/api/resrobot-reseplanerare/dokumentation/sokresa
  */
 
-const Champlain = imports.gi.Champlain;
-const GLib = imports.gi.GLib;
-const Soup = imports.gi.Soup;
+import GLib from 'gi://GLib';
+import Shumate from 'gi://Shumate';
+import Soup from 'gi://Soup';
 
-const Application = imports.application;
-const GraphHopperTransit = imports.graphHopperTransit;
-const HTTP = imports.http;
-const HVT = imports.hvt;
-const TransitPlan = imports.transitPlan;
-const Utils = imports.utils;
+import {Application} from '../application.js';
+import * as GraphHopperTransit from '../graphHopperTransit.js';
+import {Query} from '../http.js';
+import * as HVT from '../hvt.js';
+import {Itinerary, Leg, RouteType, Stop} from '../transitPlan.js';
+import * as Utils from '../utils.js';
 
 const BASE_URL = 'https://api.resrobot.se';
 const API_VERSION = 'v2.1';
@@ -88,7 +88,14 @@ const WALK_SEARCH_RADIUS = 2000;
 // maximum distance for walk-only journey
 const MAX_WALK_ONLY_DISTANCE = 2500;
 
-var Resrobot = class Resrobot {
+/* set of transit agencies where "regional rail" is interpreted as
+ * HVT.TOURIST_RAILWAY_SERVICE, e.g. heritage rail
+ */
+const TOURIST_TRAIN_AGENCIES = new Set(['Engelsberg-Norbergs Jä',
+                                        'Lennakatten',
+                                        'TJF Smalspåret']);
+
+export class Resrobot {
     constructor(params) {
         this._session = new Soup.Session({ user_agent : 'gnome-maps/' + pkg.version });
         this._plan = Application.routingDelegator.transitRouter.plan;
@@ -134,19 +141,20 @@ var Resrobot = class Resrobot {
     }
 
     _fetchNearbyStops(lat, lon, num, radius, callback) {
-        let query = new HTTP.Query(this._getNearbyStopsQueryParams(lat, lon,
-                                                                   num, radius));
-        let uri = new Soup.URI(BASE_URL + '/' + API_VERSION +
-                               '/location.nearbystops?' + query.toString());
-        let request = new Soup.Message({ method: 'GET', uri: uri });
+        let query = new Query(this._getNearbyStopsQueryParams(lat, lon,
+                                                              num, radius));
+        let uri = BASE_URL + '/' + API_VERSION + '/location.nearbystops?' + query.toString();
+        let request = Soup.Message.new('GET', uri);
 
-        this._session.queue_message(request, (obj, message) => {
-            if (message.status_code !== Soup.Status.OK) {
-                Utils.debug('Failed to get nearby stops: ' + message.status_code);
+        this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, null,
+                                          (source, res) => {
+            if (request.get_status() !== Soup.Status.OK) {
+                Utils.debug('Failed to get nearby stops: ' + request.get_status());
                 this._noRouteFound();
             } else {
                 try {
-                    let result = JSON.parse(message.response_body.data);
+                    let buffer = this._session.send_and_read_finish(res).get_data();
+                    let result = JSON.parse(Utils.getBufferText(buffer));
                     let stopLocations = result.stopLocationOrCoordLocation;
 
                     Utils.debug('nearby stops: ' + JSON.stringify(result, null, 2));
@@ -170,14 +178,14 @@ var Resrobot = class Resrobot {
     }
 
     _fetchResults() {
-        let query = new HTTP.Query(this._getQueryParams());
-        let uri = new Soup.URI(BASE_URL + '/' + API_VERSION + '/trip?' +
-                               query.toString());
-        let request = new Soup.Message({ method: 'GET', uri: uri });
+        let query = new Query(this._getQueryParams());
+        let uri = BASE_URL + '/' + API_VERSION + '/trip?' + query.toString();
+        let request = Soup.Message.new('GET', uri);
 
-        this._session.queue_message(request, (obj, message) => {
-            if (message.status_code !== Soup.Status.OK) {
-                Utils.debug('Failed to get trip: ' + message.status_code);
+        this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, null,
+                                          (source, res) => {
+            if (request.get_status() !== Soup.Status.OK) {
+                Utils.debug('Failed to get trip: ' + request.get_status());
                 /* No routes found. If this is the first search
                  * (not "load more") and the distance is short
                  * enough, generate a walk-only itinerary
@@ -203,7 +211,8 @@ var Resrobot = class Resrobot {
                 }
             } else {
                 try {
-                    let result = JSON.parse(message.response_body.data);
+                    let buffer = this._session.send_and_read_finish(res).get_data();
+                    let result = JSON.parse(Utils.getBufferText(buffer));
 
                     Utils.debug('result: ' + JSON.stringify(result, null, 2));
                     if (result.Trip) {
@@ -292,7 +301,7 @@ var Resrobot = class Resrobot {
         walkingLeg.agencyTimezoneOffset = tzOffset;
 
         let walkingItinerary =
-            new TransitPlan.Itinerary({ legs: [walkingLeg]} );
+            new Itinerary({ legs: [walkingLeg]} );
 
         walkingItinerary.adjustTimings();
 
@@ -318,7 +327,7 @@ var Resrobot = class Resrobot {
 
     _createItinerary(trip) {
         let legs = this._createLegs(trip.LegList.Leg);
-        let itinerary = new TransitPlan.Itinerary({ legs: legs });
+        let itinerary = new Itinerary({ legs: legs });
 
         itinerary.adjustTimings();
 
@@ -438,24 +447,34 @@ var Resrobot = class Resrobot {
         let polyline = this._createPolylineForLeg(leg);
         let duration = leg.duration ? this._parseDuration(leg.duration) : null;
 
-        let result = new TransitPlan.Leg({ departure:            departure,
-                                           arrival:              arrival,
-                                           from:                 from,
-                                           to:                   to,
-                                           headsign:             leg.direction,
-                                           fromCoordinate:       [origin.lat,
-                                                                  origin.lon],
-                                           toCoordinate:         [destination.lat,
-                                                                  destination.lon],
-                                           route:                route,
-                                           routeType:            routeType,
-                                           polyline:             polyline,
-                                           isTransit:            isTransit,
-                                           distance:             leg.dist,
-                                           duration:             duration,
-                                           agencyName:           agencyName,
-                                           agencyTimezoneOffset: tzOffset,
-                                           tripShortName:        route });
+        /* if the route leg is classified as regional rail and the agency
+         * is one of the heritage railways, use tourist rail to get the
+         * steam train icon
+         */
+        if ((routeType === HVT.REGIONAL_RAIL_SERVICE ||
+             routeType === HVT.SUBURBAN_RAILWAY_SERVICE ) &&
+            TOURIST_TRAIN_AGENCIES.has(agencyName)) {
+            routeType = HVT.TOURIST_RAILWAY_SERVICE;
+        }
+
+        let result = new Leg({ departure:            departure,
+                               arrival:              arrival,
+                               from:                 from,
+                               to:                   to,
+                               headsign:             leg.direction,
+                               fromCoordinate:       [origin.lat,
+                                                      origin.lon],
+                               toCoordinate:         [destination.lat,
+                                                      destination.lon],
+                               route:                route,
+                               routeType:            routeType,
+                               polyline:             polyline,
+                               isTransit:            isTransit,
+                               distance:             leg.dist,
+                               duration:             duration,
+                               agencyName:           agencyName,
+                               agencyTimezoneOffset: tzOffset,
+                               tripShortName:        route });
 
         if (isTransit)
             result.intermediateStops = this._createIntermediateStops(leg);
@@ -470,15 +489,15 @@ var Resrobot = class Resrobot {
             polyline = [];
 
             leg.Stops.Stop.forEach((stop) => {
-                polyline.push(new Champlain.Coordinate({ latitude:  stop.lat,
-                                                         longitude: stop.lon }));
+                polyline.push(new Shumate.Coordinate({ latitude:  stop.lat,
+                                                       longitude: stop.lon }));
             });
         } else {
             polyline =
-                [new Champlain.Coordinate({ latitude:  leg.Origin.lat,
-                                            longitude: leg.Origin.lon }),
-                 new Champlain.Coordinate({ latitude:  leg.Destination.lat,
-                                            longitude: leg.Destination.lon })];
+                [new Shumate.Coordinate({ latitude:  leg.Origin.lat,
+                                          longitude: leg.Origin.lon }),
+                 new Shumate.Coordinate({ latitude:  leg.Destination.lat,
+                                          longitude: leg.Destination.lon })];
         }
 
         return polyline;
@@ -512,11 +531,11 @@ var Resrobot = class Resrobot {
         if (!departure)
             departure = arrival;
 
-        return new TransitPlan.Stop({ name:                 stop.name,
-                                      arrival:              arrival,
-                                      departure:            departure,
-                                      agencyTimezoneOffset: departureTzOffset || arrivalTzOffset,
-                                      coordinate: [stop.lat, stop.lon] });
+        return new Stop({ name:                 stop.name,
+                          arrival:              arrival,
+                          departure:            departure,
+                          agencyTimezoneOffset: departureTzOffset || arrivalTzOffset,
+                          coordinate: [stop.lat, stop.lon] });
     }
 
     _getHVTCodeFromCatCode(code) {
@@ -603,15 +622,15 @@ var Resrobot = class Resrobot {
 
     _productCodeForTransitType(type) {
         switch (type) {
-            case TransitPlan.RouteType.BUS:
+            case RouteType.BUS:
                 return Products.BUS + Products.EXPRESS_BUS + Products.TAXI;
-            case TransitPlan.RouteType.TRAM:
+            case RouteType.TRAM:
                 return Products.TRAM;
-            case TransitPlan.RouteType.TRAIN:
+            case RouteType.TRAIN:
                 return Products.EXPRESS_TRAIN + Products.LOCAL_TRAIN;
-            case TransitPlan.RouteType.SUBWAY:
+            case RouteType.SUBWAY:
                 return Products.SUBWAY;
-            case TransitPlan.RouteType.FERRY:
+            case RouteType.FERRY:
                 return Products.FERRY;
             default:
                 return 0;
